Crate even_or_odd
even_
or_
odd
0.1.0
All Items
Crate Items
Functions
Crate
even_
or_
odd
Functions

is_even
Returns a bool that indicates whether or not number is even.
is_odd
Returns a bool that indicates whether or not number is odd.